from .differentiation import dxdt, methods
from .dglobal import Spectral, Spline, TrendFiltered, Kalman
from .dlocal import FiniteDifference, SavitzkyGolay

from .__version__ import __version__
